version 9.1
* rurdisp-rep2.do
* 
* Bear in mind that dtype has the following values: (See Table C in "Mediation_FullTables.doc")
*         Ownership |   1
*         Liability |   2
*          Business |   3
*           Divorce |   4
* Within own family |   5 (the value with no dummy)
*          Neighbor |   6
*         Water use |   7
*              Debt |   8


****************************************************************************************************
* Table 5: Multinomial Logistic Regression Results on Channels Through Which Help was Sought (Rural)
****************************************************************************************************

clear
set memory 10m
use rurdisp

* Drop cases of "other" forms of dispute
drop if dispute==18

* This replicates the multinomial logit
mlogit seekexp agemeanhh educyrshh income1n contactn avinc2n downer dliability dbusiness ddivorce dneighbor dwater ddebt, basecategory(1) robust

****************************************************************************
* The following creates the predicted probabilities for Table 6 and Figure 1
****************************************************************************

**********
* Predicted probabilities for eight types of disputes, all other variables at means
* Used for Table 6
**********

* Generates predictions for dispute type 1
prvalue, x(downer=1 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 2
prvalue, x(downer=0 dliability=1 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 3
prvalue, x(downer=0 dliability=0 dbusiness=1 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 4
prvalue, x(downer=0 dliability=0 dbusiness=0 ddivorce=1 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 5
prvalue, x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 6
prvalue, x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=1 dwater=0 ddebt=0)

* Generates predictions for dispute type 7
prvalue, x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=1 ddebt=0)

* Generates predictions for dispute type 8
prvalue, x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=1)



**********
* Predicted values for eight types of disputes, given a range of values on income1n, 
* all other variables at means
**********

* Generates predictions for dispute type 1
prgen income1n, generate (in1) x(downer=1 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 2
prgen income1n, generate (in2) x(downer=0 dliability=1 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 3
prgen income1n, generate (in3) x(downer=0 dliability=0 dbusiness=1 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 4
prgen income1n, generate (in4) x(downer=0 dliability=0 dbusiness=0 ddivorce=1 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 5
prgen income1n, generate (in5) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 6
prgen income1n, generate (in6) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=1 dwater=0 ddebt=0)

* Generates predictions for dispute type 7
prgen income1n, generate (in7) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=1 ddebt=0)

* Generates predictions for dispute type 8
prgen income1n, generate (in8) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=1)

* Label the predicted-values variables
label variable in1p4 "Ownership"
label variable in2p4 "Liability"
label variable in3p4 "Business"
label variable in4p4 "Divorce"
label variable in5p4 "Within-family"
label variable in6p4 "Neighbor"
label variable in7p4 "Water use"
label variable in8p4 "Debt"
label variable in1x "Log of hh income"

**********
* Predicted values for eight types of disputes, given a range of values on educyrshh, 
* all other variables at means
**********

* Generates predictions for dispute type 1
prgen educyrshh, generate (ed1) x(downer=1 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 2
prgen educyrshh, generate (ed2) x(downer=0 dliability=1 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 3
prgen educyrshh, generate (ed3) x(downer=0 dliability=0 dbusiness=1 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 4
prgen educyrshh, generate (ed4) x(downer=0 dliability=0 dbusiness=0 ddivorce=1 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 5
prgen educyrshh, generate (ed5) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 6
prgen educyrshh, generate (ed6) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=1 dwater=0 ddebt=0)

* Generates predictions for dispute type 7
prgen educyrshh, generate (ed7) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=1 ddebt=0)

* Generates predictions for dispute type 8
prgen educyrshh, generate (ed8) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=1)

* Label the predicted-values variables
label variable ed1p4 "Ownership"
label variable ed2p4 "Liability"
label variable ed3p4 "Business"
label variable ed4p4 "Divorce"
label variable ed5p4 "Within-family"
label variable ed6p4 "Neighbor"
label variable ed7p4 "Water use"
label variable ed8p4 "Debt"
label variable ed1x "Family adults' mean years of education"

**********
* Predicted values for eight types of disputes, given a range of values on contactn, 
* all other variables at means
**********

* Generates predictions for dispute type 1
prgen contactn, generate (co1) x(downer=1 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 2
prgen contactn, generate (co2) x(downer=0 dliability=1 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 3
prgen contactn, generate (co3) x(downer=0 dliability=0 dbusiness=1 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 4
prgen contactn, generate (co4) x(downer=0 dliability=0 dbusiness=0 ddivorce=1 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 5
prgen contactn, generate (co5) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 6
prgen contactn, generate (co6) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=1 dwater=0 ddebt=0)

* Generates predictions for dispute type 7
prgen contactn, generate (co7) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=1 ddebt=0)

* Generates predictions for dispute type 8
prgen contactn, generate (co8) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=1)

* Label the predicted-values variables
label variable co1p4 "Ownership"
label variable co2p4 "Liability"
label variable co3p4 "Business"
label variable co4p4 "Divorce"
label variable co5p4 "Within-family"
label variable co6p4 "Neighbor"
label variable co7p4 "Water use"
label variable co8p4 "Debt"
label variable co1x "Contacts with village committee (log)"


**********
* Predicted values for eight types of disputes, given a range of values on avinc2n, 
* all other variables at means
**********

* Generates predictions for dispute type 1
prgen avinc2n, generate (vi1) x(downer=1 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 2
prgen avinc2n, generate (vi2) x(downer=0 dliability=1 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 3
prgen avinc2n, generate (vi3) x(downer=0 dliability=0 dbusiness=1 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 4
prgen avinc2n, generate (vi4) x(downer=0 dliability=0 dbusiness=0 ddivorce=1 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 5
prgen avinc2n, generate (vi5) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=0)

* Generates predictions for dispute type 6
prgen avinc2n, generate (vi6) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=1 dwater=0 ddebt=0)

* Generates predictions for dispute type 7
prgen avinc2n, generate (vi7) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=1 ddebt=0)

* Generates predictions for dispute type 8
prgen avinc2n, generate (vi8) x(downer=0 dliability=0 dbusiness=0 ddivorce=0 dneighbor=0 dwater=0 ddebt=1)

* Label the predicted-values variables
label variable vi1p4 "Ownership"
label variable vi2p4 "Liability"
label variable vi3p4 "Business"
label variable vi4p4 "Divorce"
label variable vi5p4 "Within-family"
label variable vi6p4 "Neighbor"
label variable vi7p4 "Water use"
label variable vi8p4 "Debt"
label variable vi1x "Contacts with village committee (log)"

* Save dataset with predicted values
save rurdisp-workingp, replace

