* rurdisp-rep3.do
* creates graphs for Figure 1. The file rurdisp-rep2.do must be run first.

* Loads version of dataset with predicted values (generated by rurdisp-rep2.do)
clear
use rurdisp-workingp

* This de-logs the values of the x-variables used in three of the graphs so that they will be more intuitive
cap gen in1x_delog = exp(in1x)
cap gen co1x_delog = exp(co1x)
cap gen vi1x_delog = exp(vi1x) * 1000

* HH income / monochrome graph command
twoway connected in1p4 in1x_delog, msymbol(circle) mcolor(black) lcolor(gray)           ///
    || connected in2p4 in1x_delog, msymbol(diamond) mcolor(black) lcolor(gray)          ///
    || connected in3p4 in1x_delog, msymbol(triangle) mcolor(black) lcolor(gray)         ///
    || connected in4p4 in1x_delog, msymbol(square) mcolor(black) lcolor(gray)           ///
    || connected in5p4 in1x_delog, msymbol(plus) mcolor(black) lcolor(gray)             ///
    || connected in6p4 in1x_delog, msymbol(X) mcolor(black) lcolor(gray)                ///
    || connected in7p4 in1x_delog, msymbol(triangle_hollow) mcolor(black) lcolor(gray)  ///
    || connected in8p4 in1x_delog, msymbol(square_hollow) mcolor(black) lcolor(gray)    ///
    || ,                                                                        ///
        ytitle("Probability of seeking mediation", size(3))                     ///
        ylabel(,labsize(3))                                                     ///
        xscale(log)                                                             /// 
        xlabel(300 500 1000 3000 10000 30000 100000, labsize(3))                ///
        xtitle("Annual household income (yuan, logged scale)", size(3))         ///
        xlabel(,labsize(3))                                                     ///
        title("Income and mediation by dispute type, rural", size(4))           ///
        legend(order(4 1 6 2 7 8 5 3) title("Dispute type:", color(black) size(3)))
graph export Income-Mediation-Mono.wmf, replace


* VC contact / monochrome graph command
twoway connected co1p4 co1x_delog, msymbol(circle) mcolor(black) lcolor(gray)           ///
    || connected co2p4 co1x_delog, msymbol(diamond) mcolor(black) lcolor(gray)          ///
    || connected co3p4 co1x_delog, msymbol(triangle) mcolor(black) lcolor(gray)         ///
    || connected co4p4 co1x_delog, msymbol(square) mcolor(black) lcolor(gray)           ///
    || connected co5p4 co1x_delog, msymbol(plus) mcolor(black) lcolor(gray)             ///
    || connected co6p4 co1x_delog, msymbol(X) mcolor(black) lcolor(gray)                ///
    || connected co7p4 co1x_delog, msymbol(triangle_hollow) mcolor(black) lcolor(gray)  ///
    || connected co8p4 co1x_delog, msymbol(square_hollow) mcolor(black) lcolor(gray)    ///
    || ,                                                                  ///
        ytitle("Probability of seeking mediation", size(3))               ///
        ylabel(,labsize(3))                                               ///
        xscale(log)                                                       /// 
        xlabel(1 3 10 30 100 400 1500,labsize(3))                                               ///
        xtitle("Contacts with village committee in two years (logged scale)", size(3))                ///
        title("VC contact and mediation by dispute type, rural", size(4)) ///
        legend(order(4 1 6 2 7 8 5 3) title("Dispute type:", color(black) size(3)))
graph export Contacts-Mediation-Mono.wmf, replace

* Village mediation by education / monochrome graph command
twoway connected ed1p4 ed1x, msymbol(circle) mcolor(black) lcolor(gray)   ///
    || connected ed2p4 ed1x, msymbol(diamond) mcolor(black) lcolor(gray)  ///
    || connected ed3p4 ed1x, msymbol(triangle) mcolor(black) lcolor(gray) ///
    || connected ed4p4 ed1x, msymbol(square) mcolor(black) lcolor(gray)   ///
    || connected ed5p4 ed1x, msymbol(plus) mcolor(black) lcolor(gray)     ///
    || connected ed6p4 ed1x, msymbol(X) mcolor(black) lcolor(gray)        ///
    || connected ed7p4 ed1x, msymbol(triangle_hollow) mcolor(black) lcolor(gray)        ///
    || connected ed8p4 ed1x, msymbol(square_hollow) mcolor(black) lcolor(gray)        ///
    || ,                                                                  ///
        ytitle("Probability of seeking mediation", size(3))               ///
        ylabel(,labsize(3))                                               ///
        xtitle("Years of education (mean of household adults)", size(3))                             ///
        xlabel(,labsize(3))                                               ///
        title("Education and mediation by dispute type, rural", size(4))  ///
        legend(order(4 1 6 2 7 8 5 3) title("Dispute type:", color(black) size(3)))
graph export Education-Mediation-Mono.wmf, replace

* Village income / monochrome graph command
twoway connected vi1p4 vi1x_delog, msymbol(circle) mcolor(black) lcolor(gray)   ///
    || connected vi2p4 vi1x_delog, msymbol(diamond) mcolor(black) lcolor(gray)  ///
    || connected vi3p4 vi1x_delog, msymbol(triangle) mcolor(black) lcolor(gray) ///
    || connected vi4p4 vi1x_delog, msymbol(square) mcolor(black) lcolor(gray)   ///
    || connected vi5p4 vi1x_delog, msymbol(plus) mcolor(black) lcolor(gray)     ///
    || connected vi6p4 vi1x_delog, msymbol(X) mcolor(black) lcolor(gray)        ///
    || connected vi7p5 vi1x_delog, msymbol(triangle_hollow) mcolor(black) lcolor(gray)        ///
    || connected vi8p5 vi1x_delog, msymbol(square_hollow) mcolor(black) lcolor(gray)        ///
    || ,                                                                  ///
        ytitle("Probability of seeking mediation", size(3))               ///
        ylabel(,labsize(3))                                               ///
        xscale(log)                                                             /// 
        xlabel(3000 6000 10000 18000 30000, labsize(3))                ///
        xtitle("Village average household income (yuan, logged scale)", size(3))                 ///
        title("Village income and mediation by dispute type, rural", size(4)) ///
        legend(order(4 1 6 2 7 8 5 3)                                                       ///
          label(1 "Ownership") label(2 "Liability") label(3 "Business") label(4 "Divorce")  ///
          label(5 "Within family") label(6 "Neighbor") label(7 "Water use") label(8 "Debt") ///
          title("Dispute type:", color(black) size(3)))
graph export VillInc-Mediation-Mono.wmf, replace


